@@ -1,22 +1,22 @@
-# logger = getLogger("HTTPBuffer")
+from base64 import b64encode, b64decode
 
 class Buffer(object):
     ''' A Buffer object buffers text, and has two modes, 'index' and 'consume'
-        
+
         In index mode, which is the default initial mode of a Buffer object,
         the buffer object keeps track of a position 'pos', which can be
         altered by calling b.move, or by b.exhaust, which moves 'pos' to the
-        end of the file.  ... TODO: finish this
-        
+        end of the file.
+
         In consume mode, a buffer essentially just a proxy for its contained
         string b.data.
     '''
     def __init__(self, initial_data='', mode='index'):
         self.mode = None
         self.pos = None
-        self.data = initial_data        
+        self.data = initial_data
         self.set_mode(mode)
-    
+
     def set_mode(self, mode):
         # No change
         if self.mode == mode:
@@ -31,10 +31,10 @@ class Buffer(object):
             self.pos = None
             self.mode = 'consume'
         # initial mode is consume
-        else: 
+        else:
             self.mode = 'consume'
             self.pos = None
-    
+
     def find(self, marker, i=0):
         if self.mode == 'consume':
             return self.data.find(marker, i)
@@ -43,10 +43,10 @@ class Buffer(object):
             if pos == -1:
                 return -1
             return pos - self.pos
-    
+
     def __str__(self):
         return self.get_value()
-    
+
     def get_value(self):
         ''' Return the data in consume mode, or the remainder of the data in
             index mode.
@@ -55,11 +55,11 @@ class Buffer(object):
             return self.data
         elif self.mode == 'index':
             return self.data[self.pos:]
-    
+
     def get_full_value(self):
         ''' Returns the full value of the string, even in index mode. '''
         return self.data
-    
+
     def exhaust(self):
         ''' In index mode, sets position to the end of the buffered data.  In
             consume mode, sets data to empty.
@@ -68,12 +68,12 @@ class Buffer(object):
             self.data = ''
         elif self.mode == 'index':
             self.pos = len(self.data)
-    
+
     def reset_position(self):
         ''' Resets position to 0. '''
         if self.mode == 'index':
             self.pos = 0
-    
+
     def reset(self, content = ''):
         ''' Resets data to empty, or an opional 'content' string, and position
             to 0.
@@ -81,52 +81,82 @@ class Buffer(object):
         self.data = content
         if self.mode == 'index':
             self.pos = 0
-    
+
     def empty(self):
         ''' Boolean; is true if the the buffer is empty '''
         if self.mode == 'consume':
             return len(self.data) == 0
         elif self.mode == 'index':
             return (len(self.data) - self.pos) == 0
-    
+
     def move(self, i):
         if self.mode == 'consume':
             self.data = self.data[i:]
         elif self.mode == 'index':
             self.pos += i
-    
+
     def part(self, start, end):
         if self.mode == 'consume':
             return self.data[start:end]
         elif self.mode == 'index':
             return self.data[self.pos + start: self.pos + end]
-    
+
     def __contains__(self, data):
         if self.mode == 'consume':
             return data in self.data
         elif self.mode == 'index':
             return self.data.find(data, self.pos) != -1
-    
+
     def __eq__(self, data):
         if self.mode == 'consume':
             return self.data == data
         elif self.mode == 'index':
             return self.data[self.pos:] == data
-    
+
     def __len__(self):
         if self.mode == 'consume':
             return len(self.data)
         elif self.mode == 'index':
             return len(self.data) - self.pos
-    
+
     def __get_slice__(self, start, end):
         return self.part(self, start, end)
-    
+
     def __add__(self, add_data):
         ''' Add the passed-in string to the buffer '''
-#        if not isinstance(add_data, str):
-#            print 'add_data', add_data, add_data.__class__
-#            raise TypeError
         self.data += add_data
-        return self        
-    
+        return self
+
+class B64ReadBuffer(Buffer):
+    ''' This works exactly like the Buffer class, except it
+        reads base64-encoded strings separated by whitespace.
+    '''
+    def __init__(self, initial_data='', mode='index'):
+        self.mode = None
+        self.pos = None
+        self.data = initial_data
+        self.raw_data = ''
+        self.set_mode(mode)
+
+    def __add__(self, add_data):
+        ''' Add the passed-in base64-encoded string to the pre-buffer '''
+        s = add_data.find(' ')
+        if s != -1:
+            self.data += b64decode(self.raw_data+add_data[:s])
+            add_data = add_data[s+1:]
+            self.raw_data = ''
+        self.raw_data += add_data
+        return self
+
+class B64WriteBuffer(Buffer):
+    ''' This works exactly like the Buffer class, except
+        get_value() returns a base64-encoded string
+    '''
+    def get_value(self):
+        ''' Return the base64-encoded data in consume mode, or the base64-encoded remainder of the data in
+            index mode.
+        '''
+        if self.mode == 'consume':
+            return b64encode(self.data)+' '
+        elif self.mode == 'index':
+            return b64encode(self.data[self.pos:])+' '
\ No newline at end of file
