@@ -1,9 +1,8 @@
-
 class FakeLogger(object):
     def debug(self, *args, **kwargs):
         pass
     info = debug
-    acess = debug
+    access = debug
     warn = debug
     error = debug
     
